---
sd_hide_title: true
---

# Python API

## API reference

The ``plinder.core`` package provides utilities for interacting with the PLINDER dataset.

It contains an additional ``plinder.core.scores`` sub-package for querying parquet collections.

:::{toctree}
:maxdepth: 1
:hidden:
:glob:

./*/index
:::
